# 终端


### 可选参数：
```shell
-v, --version          获取 Bomiot 版本
-h, --help             显示此帮助信息并退出
```

### 可用命令：

```shell
new                    为项目创建应用
project                项目工作区，默认为 bomiot
plugins                插件工作区，默认为 bomiot
deploy                 部署项目
init                   初始化 bomiot
initadmin              创建默认超级用户 admin
initpwd                初始化 admin 密码
migrate                迁移数据库
makemigrations         生成数据库迁移文件
loaddata               从配置加载数据
dumpdata               将数据导出到配置
market                 从市场复制项目
keys                   初始化认证密钥
run                    运行服务器
```